/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal        *
* Robbery:  Prevalence, Trends, and Factors in Sentencing report Event file and create   *
* a SAS dataset.                                                                         *   
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Robbery_Event_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Robbery_Event_Public ;

DATA library.&dataset ;
INFILE datafile LRECL=109;
INPUT
   USSCIDN  1-8             EVENT_ID  9-16           NOPROP_TAKEN  17-19   
   CASH_TAKEN  20-22        VEHICLE_TAKEN  23-25     DRUGS_TAKEN  26-28    
   FIREARMS_TAKEN  29-31    MERCH_TAKEN  32-34       PERSPROP_TAKEN  35-37 
   ROBWHERE  38-40          OFFALONE  41-43          NUMCONSP  44-46       
   WEAP_WHO  47-49          INJURYNUM  50-52         THREAT_ANY  53-55     
   FORCE_ANY  56-58         WEAP_ANY  59-61       
   THREAT_HOW_DISCHARGE_ANY  62-64   THREAT_HOW_WEAP_ANY  65-67
   FORCE_HOW_CONTACT_ANY  68-70   INJURY_YES  71-73     
   DEATH_YES  74-76         FORCE_HOW_DISCHARGE_ANY  77-79
   THREAT_HOW_VERBAL_ANY  80-82   THREAT_HOW_WRITE_ANY  83-85
   THREAT_HOW_BODYLANG_ANY  86-88   THREAT_HOW_OTHER_ANY  89-91
   FORCE_HOW_OTHER_ANY  92-94   ALL_OTHER_TAKEN  95-97
   WEAP_TYPE_FIREARM_EITHER  98-100   WEAP_TYPE_KNIFE_ANY  101-103
   WEAP_TYPE_FAKEGUN_EITHER  104-106   WEAP_TYPE_ALL_OTHER_ANY  107-109
 ;                       

LENGTH
   USSCIDN 6                EVENT_ID 4               NOPROP_TAKEN 3        
   CASH_TAKEN 3             VEHICLE_TAKEN 3          DRUGS_TAKEN 3         
   FIREARMS_TAKEN 3         MERCH_TAKEN 3            PERSPROP_TAKEN 3      
   ROBWHERE 3               OFFALONE 3               NUMCONSP 3            
   WEAP_WHO 3               INJURYNUM 3              THREAT_ANY 3          
   FORCE_ANY 3              WEAP_ANY 3               THREAT_HOW_DISCHARGE_ANY 3
   THREAT_HOW_WEAP_ANY 3    FORCE_HOW_CONTACT_ANY 3   INJURY_YES 3          
   DEATH_YES 3              FORCE_HOW_DISCHARGE_ANY 3   THREAT_HOW_VERBAL_ANY 3
   THREAT_HOW_WRITE_ANY 3   THREAT_HOW_BODYLANG_ANY 3   THREAT_HOW_OTHER_ANY 3
   FORCE_HOW_OTHER_ANY 3    ALL_OTHER_TAKEN 3        WEAP_TYPE_FIREARM_EITHER 3
   WEAP_TYPE_KNIFE_ANY 3    WEAP_TYPE_FAKEGUN_EITHER 3   WEAP_TYPE_ALL_OTHER_ANY 3 ;



RUN ;
