/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's Federal        *
* Robbery:  Prevalence, Trends, and Factors in Sentencing report Main file and create    *
* a SAS dataset.                                                                         *   
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\USSC_Robbery_Main_Public.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = USSC_Robbery_Main_Public ;

DATA library.&dataset ;
INFILE datafile LRECL=380;
INPUT
   USSCIDN  1-7             EVENTNUM  8-10           FLAG_HOMICIDE  11-13  
   FLAG_RAPE  14-16         FLAG_ROBBERY  17-19      FLAG_ASSAULT  20-22   
   FLAG_OTHER_VIOLENT  23-25   FLAG_BURGLARY  26-28     FLAG_LARCENY  29-31   
   FLAG_FRAUD  32-34        FLAG_OTHER_PROPERTY  35-37
   FLAG_DRUG_TRAFFIC  38-40   FLAG_DRUG_POSSESS  41-43   FLAG_OTHER_DRUG  44-46
   FLAG_WEAPON  47-49       FLAG_DUI  50-52          FLAG_IMMIGRATION  53-55
   FLAG_PUBLIC_ORDER  56-58   FLAG_UNSPECIFIED  59-61   FLAG_VIOLENT  62-64   
   ROB_CAT  65-67           VIOLENT  68-71           AGE  72-75            
   TOTCHPTS  76-79          XCRHISSR  80-83          AMENDYR  84-88        
   GDLINEHI $ 89-94         FY  95-98                SENSPCAP  99-116      
   SENTTCAP  117-134        PCNTDEPT  135-152        MNTHDEPT  153-171     
   SENTRNGE  172-179        GLMIN  180-187           CIRCDIST  188-191     
   IS924C  192-195          MONRACE  196-199         MONSEX  200-203       
   NEWCIT  204-207          NEWRACE  208-211         SENTIMP  212-215      
   GUNMIN1  216-220         OFFGUIDE  221-224        ACCAP  225-228        
   CAROFFAP  229-232        ADJ_BHI  233-236         ADJ_CHI  237-240      
   ADJ_DHI  241-244         ADJ_EHI  245-248         ADJ_FHI  249-252      
   ADJ_GHI  253-256         ADJ_HHI  257-260         GDSTATHI $ 261-266    
   STAT_182111  267-269     STAT_182112  270-272     STAT_182113  273-275  
   STAT_182114  276-278     STAT_182114A  279-281    STAT_182116  282-284  
   STAT_182118  285-287     STAT_182119  288-290     STAT_181951  291-293  
   STAT_18371  294-296      STAT_18922  297-299      STAT_18922G  300-302  
   STAT_181959  303-305     STAT_181962  306-308     STAT_182113_ROB  309-311
   STAT_182118_ROB  312-314   NEWEDUC  315-318         SOURCES  319-322      
   ADJ_IHI  323-326         ADJ_JHI  327-330         ADJ_KHI  331-334      
   ADJ_LHI  335-338         ADJ_MHI  339-342         ADJ_NHI  343-346      
   ADJ_OHI  347-350         ADJ_PHI  351-354         ADJ_QHI  355-358      
   ADJ_RHI  359-362         ADJ_SHI  363-366         ADJ_THI  367-370      
   ADJ_UHI  371-374         TOTALOTHER  375-377      LENGTH  378-380       
 ;                       

LENGTH
   USSCIDN 6                EVENTNUM 3               FLAG_HOMICIDE 3       
   FLAG_RAPE 3              FLAG_ROBBERY 3           FLAG_ASSAULT 3        
   FLAG_OTHER_VIOLENT 3     FLAG_BURGLARY 3          FLAG_LARCENY 3        
   FLAG_FRAUD 3             FLAG_OTHER_PROPERTY 3    FLAG_DRUG_TRAFFIC 3   
   FLAG_DRUG_POSSESS 3      FLAG_OTHER_DRUG 3        FLAG_WEAPON 3         
   FLAG_DUI 3               FLAG_IMMIGRATION 3       FLAG_PUBLIC_ORDER 3   
   FLAG_UNSPECIFIED 3       FLAG_VIOLENT 3           ROB_CAT 3             
   VIOLENT 3                AGE 3                    TOTCHPTS 3            
   XCRHISSR 3               AMENDYR 4                FY 4                  
   SENTRNGE 3               GLMIN 4                  CIRCDIST 3            
   IS924C 3                 MONRACE 3                MONSEX 3              
   NEWCIT 3                 NEWRACE 3                SENTIMP 3             
   GUNMIN1 4                OFFGUIDE 3               ACCAP 3               
   CAROFFAP 3               ADJ_BHI 3                ADJ_CHI 3             
   ADJ_DHI 3                ADJ_EHI 3                ADJ_FHI 3             
   ADJ_GHI 3                ADJ_HHI 3                STAT_182111 3         
   STAT_182112 3            STAT_182113 3            STAT_182114 3         
   STAT_182114A 3           STAT_182116 3            STAT_182118 3         
   STAT_182119 3            STAT_181951 3            STAT_18371 3          
   STAT_18922 3             STAT_18922G 3            STAT_181959 3         
   STAT_181962 3            STAT_182113_ROB 3        STAT_182118_ROB 3     
   NEWEDUC 3                SOURCES 3                ADJ_IHI 3             
   ADJ_JHI 3                ADJ_KHI 3                ADJ_LHI 3             
   ADJ_MHI 3                ADJ_NHI 3                ADJ_OHI 3             
   ADJ_PHI 3                ADJ_QHI 3                ADJ_RHI 3             
   ADJ_SHI 3                ADJ_THI 3                ADJ_UHI 3             
   TOTALOTHER 3             LENGTH 3 ;

          

RUN ;
